@@ -1,6 +1,7 @@
 """Code for supporting compatibility across python versions."""
 
 import sys
+import warnings
 from imp import find_module as original_find_module
 
 
@@ -36,3 +37,21 @@ else:
     unicode_errors_default = 'strict'
 
 NUM_TYPES = (int, long, float)
+
+
+def check_async(async_, kwargs, default):
+    """Return a value of 'async' in kwargs or default when async_ is None.
+
+    This helper function exists for backward compatibility (See #274).
+    It shows a warning message when 'async' in kwargs is used to note users.
+    """
+    if async_ is not None:
+        return async_
+    elif 'async' in kwargs:
+        warnings.warn(
+            '"async" attribute is deprecated. Use "async_" instead.',
+            DeprecationWarning,
+        )
+        return kwargs.pop('async')
+    else:
+        return default
